# eric7.WebBrowser.WebBrowserSnap

Module implementing functions to generate page previews.

### Global Attributes

None

### Classes

None

### Functions

__render | Private function to render a pixmap of given size for a web page.
renderTabPreview | Public function to render a pixmap of a page.

## __render

__render(view, w, h)

Private function to render a pixmap of given size for a web page.

view (QWebEngineView)
  reference to the view to be previewed
w (int)
  width of the pixmap
h (int)
  height of the pixmap

Return:
  rendered pixmap

Return Type:
  QPixmap

Up

## renderTabPreview

renderTabPreview(view, w, h)

Public function to render a pixmap of a page.

view (QWebEngineView)
  reference to the view to be previewed
w (int)
  width of the preview pixmap
h (int)
  height of the preview pixmap

Return:
  preview pixmap

Return Type:
  QPixmap

Up